==> jaysonic-1.2.1.tgz: package/lib/server/http.js <==
"use strict";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

var http = require("http");

var Server = require(".");

var _require = require("../constants"),
    errorToStatus = _require.errorToStatus;
/**
 * Constructor for Jsonic HTTP server
 * @class HTTPServer
 * @constructor
 * @extends Client
 * @param {Object} [options] optional settings for server
 * @return HTTPServer
 */


var HTTPServer =
/*#__PURE__*/
function (_Server) {
  _inherits(HTTPServer, _Server);

  function HTTPServer(options) {
    var _this;

    _classCallCheck(this, HTTPServer);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(HTTPServer).call(this, options));
    _this.connectedClients = [];
    _this.responseBuffer = [];

    _this.initserver();

    return _this;
  }

  _createClass(HTTPServer, [{
    key: "initserver",
    value: function initserver() {
      var _this2 = this;

      this.server = new http.Server();
      this.server.on("connection", function (client) {
        _this2.connectedClients.push(client);

        client.on("close", function () {
          _this2.emit("clientDisconnected");
        });
        client.on("end", function () {
          _this2.emit("clientDisconnected");
        });
      });
    }
  }, {
    key: "handleData",
    value: function handleData() {
      var _this3 = this;

      this.server.on("request", function (request, response) {
        request.on("data", function (data) {
          _this3.messageBuffer += data;
        });
        request.on("end", function () {
          var messages = _this3.messageBuffer.split(_this3.options.delimiter);

          _this3.messageBuffer = "";
          messages.filter(function (messageString) {
            return messageString !== "";
          }).map(function (chunk) {
            return Promise.all(_this3.handleValidation(chunk)).then(function (validationResult) {
              var message = validationResult[1];

              if (message.batch) {
                _this3.setResponseHeader({
                  response: response
                });

                response.write(JSON.stringify(message.batch) + _this3.options.delimiter, function () {
                  response.end();
                });
              } else if (message.notification) {
                _this3.setResponseHeader({
                  response: response,
                  notification: true
                });

                response.end();
              } else {
                _this3.getResult(message).then(function (result) {
                  _this3.setResponseHeader({
                    response: response
                  });

                  response.write(result + _this3.options.delimiter, function () {
                    response.end();
                  });
                })["catch"](function (error) {
                  _this3.setResponseHeader({
                    response: response,
                    errorCode: error.error.code
                  });

                  response.write(JSON.stringify(error) + _this3.options.delimiter, function () {
                    response.end();
                  });
                });
              }
            })["catch"](function (error) {
              _this3.setResponseHeader({
                response: response,
                errorCode: error.code
              });

              response.write(JSON.stringify(error) + _this3.options.delimiter, function () {
                response.end();
              });
            });
          });
        });
      });
    }
  }, {
    key: "setResponseHeader",
    value: function setResponseHeader(_ref) {
      var response = _ref.response,
          errorCode = _ref.errorCode,
          notification = _ref.notification;
      var statusCode = 200;

      if (notification) {
        statusCode = 204;
      }

      var header = {
        "Content-Type": "application/json"
      };

      if (errorCode) {
        statusCode = errorToStatus[String(errorCode)];
      }

      response.writeHead(statusCode, header);
    }
  }, {
    key: "clientConnected",
    value: function clientConnected(cb) {
      this.on("clientConnected", function (client) {
        cb({
          host: client.remoteAddress,
          port: client.remotePort
        });
      });
    }
  }, {
    key: "clientDisconnected",
    value: function clientDisconnected(cb) {
      var _this4 = this;

      this.on("clientDisconnected", function (client) {
        var clientIndex = _this4.connectedClients.findIndex(function (c) {
          return client === c;
        });

        if (clientIndex === -1) {
          return "unknown";
        }

        var _this4$connectedClien = _this4.connectedClients.splice(clientIndex, 1),
            _this4$connectedClien2 = _slicedToArray(_this4$connectedClien, 1),
            deletedClient = _this4$connectedClien2[0];

        return cb({
          host: deletedClient.remoteAddress,
          port: deletedClient.remotePort
        });
      });
    }
  }]);

  return HTTPServer;
}(Server);

module.exports = HTTPServer;

==> jaysonic-1.3.2.tgz: package/lib/server/http.js <==
"use strict";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

var http = require("http");

var Server = require(".");

var _require = require("../constants"),
    errorToStatus = _require.errorToStatus;
/**
 * Constructor for Jsonic HTTP server
 * @class HTTPServer
 * @constructor
 * @extends Client
 * @param {Object} [options] optional settings for server
 * @return HTTPServer
 */


var HTTPServer =
/*#__PURE__*/
function (_Server) {
  _inherits(HTTPServer, _Server);

  function HTTPServer(options) {
    var _this;

    _classCallCheck(this, HTTPServer);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(HTTPServer).call(this, options));
    _this.connectedClients = [];
    _this.responseBuffer = [];

    _this.initserver();

    return _this;
  }

  _createClass(HTTPServer, [{
    key: "initserver",
    value: function initserver() {
      var _this2 = this;

      this.server = new http.Server();
      this.server.on("connection", function (client) {
        _this2.connectedClients.push(client);

        client.on("close", function () {
          _this2.emit("clientDisconnected");
        });
        client.on("end", function () {
          _this2.emit("clientDisconnected");
        });
      });
    }
  }, {
    key: "handleData",
    value: function handleData() {
      var _this3 = this;

      this.server.on("request", function (request, response) {
        request.on("data", function (data) {
          _this3.messageBuffer.push(data);
        });
        request.on("end", function () {
          while (!_this3.messageBuffer.isFinished()) {
            var chunk = _this3.messageBuffer.handleData();

            Promise.all(_this3.handleValidation(chunk)).then(function (validationResult) {
              var message = validationResult[1];

              if (message.batch) {
                _this3.setResponseHeader({
                  response: response
                });

                response.write(JSON.stringify(message.batch) + _this3.options.delimiter, function () {
                  response.end();
                });
              } else if (message.notification) {
                _this3.setResponseHeader({
                  response: response,
                  notification: true
                });

                response.end();
              } else {
                _this3.getResult(message).then(function (result) {
                  _this3.setResponseHeader({
                    response: response
                  });

                  response.write(result + _this3.options.delimiter, function () {
                    response.end();
                  });
                })["catch"](function (error) {
                  _this3.setResponseHeader({
                    response: response,
                    errorCode: error.error.code
                  });

                  response.write(JSON.stringify(error) + _this3.options.delimiter, function () {
                    response.end();
                  });
                });
              }
            })["catch"](function (error) {
              _this3.setResponseHeader({
                response: response,
                errorCode: error.code
              });

              response.write(JSON.stringify(error) + _this3.options.delimiter, function () {
                response.end();
              });
            });
          }
        });
      });
    }
  }, {
    key: "setResponseHeader",
    value: function setResponseHeader(_ref) {
      var response = _ref.response,
          errorCode = _ref.errorCode,
          notification = _ref.notification;
      var statusCode = 200;

      if (notification) {
        statusCode = 204;
      }

      var header = {
        "Content-Type": "application/json"
      };

      if (errorCode) {
        statusCode = errorToStatus[String(errorCode)];
      }

      response.writeHead(statusCode, header);
    }
  }, {
    key: "clientConnected",
    value: function clientConnected(cb) {
      this.on("clientConnected", function (client) {
        cb({
          host: client.remoteAddress,
          port: client.remotePort
        });
      });
    }
  }, {
    key: "clientDisconnected",
    value: function clientDisconnected(cb) {
      var _this4 = this;

      this.on("clientDisconnected", function (client) {
        var clientIndex = _this4.connectedClients.findIndex(function (c) {
          return client === c;
        });

        if (clientIndex === -1) {
          return "unknown";
        }

        var _this4$connectedClien = _this4.connectedClients.splice(clientIndex, 1),
            _this4$connectedClien2 = _slicedToArray(_this4$connectedClien, 1),
            deletedClient = _this4$connectedClien2[0];

        return cb({
          host: deletedClient.remoteAddress,
          port: deletedClient.remotePort
        });
      });
    }
  }]);

  return HTTPServer;
}(Server);

module.exports = HTTPServer;
